// Copyright (c) 2014-2020 NetEase, Inc.
// All right reserved.

part of whiteboard_core;

class RoomWBLoginInfo {
  late final NEWhiteboardVersion version;
  late final String account;
  late final String token;
  late final String channelName;
  late final String platform;
  late final String appKey;
  int? uid; // G2登陆时使用
  String? nickname;
  String? url;
  bool? record;
  bool? debug;
  Map? privateConf;
  Map? extras;

  RoomWBLoginInfo({
    this.version = NEWhiteboardVersion.G1,
    required this.account,
    required this.token,
    required this.channelName,
    required this.platform,
    required this.appKey,
    required this.nickname,
    this.uid,
    this.url,
    this.debug,
    this.record,
    this.privateConf,
    this.extras,
  });

  RoomWBLoginInfo.fromJson(Map<String, dynamic> json) {
    account = json['account'] as String;
    token = json['token'] as String;
    channelName = json['channelName'] as String;
    platform = json['platform'] as String;
    appKey = json['appKey'] as String;
    nickname = (json['nickname'] ?? '') as String;
    record = (json['record'] ?? false) as bool;
    debug = (json['debug'] ?? false) as bool;
    url = (json['url'] ?? defaultWhiteBoardUrlG2) as String;
    privateConf = json['privateConf'] as Map?;
  }

  Map<String, dynamic> toJson() {
    final data = <String, dynamic>{};
    data['account'] = account;
    data['token'] = token;
    data['channelName'] = channelName;
    data['record'] = record;
    data['debug'] = debug;
    data['platform'] = platform;
    data['appKey'] = appKey;
    data['nickname'] = nickname;
    data['uid'] = uid;
    if (version == NEWhiteboardVersion.G2) {
      data['privateConf'] = privateConf;
    } else {
      data['imParams'] = {
        "privateConf": privateConf,
      };
    }
    data.addAll(extras?.cast() ?? {});
    return data;
  }

  @override
  String toString() =>
      'RoomWBLoginInfo{account: $account, token: $token, channelName: $channelName, platform: $platform, appKey: $appKey, nickname: $nickname, url: $url, record: $record, debug: $debug, privateConf: $privateConf}';
}
